# tickle: A rock climbing ticklist manager.

This is a web application for managing your rock climbing ticklists. It is
written as a Django app.

Currently it's not in a consumable state, but eventually I'm hoping to release
this as a PyPi package which will be usable as an import in Django websites.
